==> nextcloud-app-mail-0.15.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/eu.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Inbox" : "Sarrera ontzia",
    "Sent" : "Bidalia",
    "Drafts" : "Zirriborroak",
    "Archive" : "Artxibatu",
    "Trash" : "Zakarrontzia",
    "Junk" : "Zaborra",
    "All" : "Denak",
    "Favorites" : "Gogokoak",
    "Auto detect failed. Please use manual mode." : "Autodetekzioa huts egin du. Erabili eskuzko modua",
    "Creating account failed: " : "Huts egin du kontua sortzerakoan:",
    "Delete permanently" : "Ezabatu betirako",
    "IMAP web client" : "IMAP web bezeroa",
    "Name" : "Izena",
    "Mail Address" : "Eposta helbidea",
    "Password" : "Pasahitza",
    "IMAP Host" : "IMAP ostalaria",
    "None" : "Ezer",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP portua",
    "IMAP User" : "IMAP erabiltzailea",
    "IMAP Password" : "IMAP pasahitza",
    "SMTP Host" : "SMTP ostalaria",
    "SMTP Port" : "SMTP portua",
    "SMTP User" : "SMTP erabiltzailea",
    "SMTP Password" : "SMTP pasahitza",
    "Connect" : "Konektatu",
    "Add mail account" : "Eposta helbidea gehitu",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "from" : "Nondik",
    "to" : "nora",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Gaia",
    "Sending …" : "Bidaltzen...",
    "Message sent!" : "Mezua bidali egin da!",
    "Send" : "Bidali",
    "Upload attachment" : "Eranskina igo",
    "Add attachment from Files" : "Eranskina gehitu fitxategitik",
    "Choose a file to add as attachment" : "Hautatu fitxategia gehitzeko eranskin gisa",
    "Delete" : "Ezabatu",
    "Import into calendar" : "Egutegian inportatu",
    "Download attachment" : "Eranskina jaitsi",
    "Save to Files" : "Fitxategitan gorde",
    "Choose a folder to store the attachment in" : "Hautatu karpeta bat eranskina gordetzeko",
    "Save all to Files" : "Dena fitxategitan gorde",
    "The images have been blocked to protect your privacy." : "Irudiak blokeatu dira zure segurtasunerako",
    "New message" : "Mezu berria",
    "Settings" : "Ezarpenak",
    "Show all folders" : "Erakutsi karpeta guztiak",
    "Collapse folders" : "Bildu karpetak",
    "Speed up your Mail experience with these quick shortcuts." : "Zure Mail erabilpena azkartu lasterbide azkar hauekin",
    "Compose new message" : "Mezu berria idatzi",
    "Newer message" : "Mezu berriagoa",
    "Older message" : "Mezu zaharragoa",
    "Toggle star" : "Izarra aldatu",
    "Toggle unread" : "Irakurria aldatu",
    "Search" : "Bilatu",
    "Refresh" : "Birkargatu",
    "Connect your mail account" : "Konektatu zure eposta kontua",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mezu berri \njaso dituzu {from}-etik","%n mezu berri \njaso dituzu {from}-etik"],
    "Nextcloud Mail" : "Nextcloud eposta",
    "All inboxes" : "Postontzi guztiak",
    "Could not load {tag}{name}{endtag}" : "Ezin izan da {tag}{name}{endtag} kargatu",
    "There was a problem loading {tag}{name}{endtag}" : "Akats bat egon da {tag}{name}{endtag} kargatzerakoan",
    "Error loading message" : "Akatsa mezua kargatzerakoan",
    "Forwarding to %s" : "%s birbidaltzen",
    "Click here if you are not automatically redirected within the next few seconds." : "Sakatu hemen hurrengo segunduetan automatikoki birbideratzen ez bada.",
    "Redirect" : "Birbideratu",
    "The link leads to %s" : "Estekak 1%s-ra apuntatzen du",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ez baduzu webgune horretara joan nahi <a href=\"%s\">Mail</a>  webgunera itzul zaitezke",
    "Continue to %s" : "1%s-ra jarraitu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.15.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/eu.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Inbox" : "Sarrera ontzia",
    "Sent" : "Bidalia",
    "Drafts" : "Zirriborroak",
    "Archive" : "Artxibatu",
    "Trash" : "Zakarrontzia",
    "Junk" : "Zaborra",
    "All" : "Denak",
    "Favorites" : "Gogokoak",
    "Auto detect failed. Please use manual mode." : "Autodetekzioa huts egin du. Erabili eskuzko modua",
    "Creating account failed: " : "Huts egin du kontua sortzerakoan:",
    "Delete permanently" : "Ezabatu betirako",
    "IMAP web client" : "IMAP web bezeroa",
    "Name" : "Izena",
    "Mail Address" : "Eposta helbidea",
    "Password" : "Pasahitza",
    "IMAP Host" : "IMAP ostalaria",
    "None" : "Ezer",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP portua",
    "IMAP User" : "IMAP erabiltzailea",
    "IMAP Password" : "IMAP pasahitza",
    "SMTP Host" : "SMTP ostalaria",
    "SMTP Port" : "SMTP portua",
    "SMTP User" : "SMTP erabiltzailea",
    "SMTP Password" : "SMTP pasahitza",
    "Connect" : "Konektatu",
    "Add mail account" : "Eposta helbidea gehitu",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "from" : "Nondik",
    "to" : "nora",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Gaia",
    "Sending …" : "Bidaltzen...",
    "Message sent!" : "Mezua bidali egin da!",
    "Send" : "Bidali",
    "Upload attachment" : "Eranskina igo",
    "Add attachment from Files" : "Eranskina gehitu fitxategitik",
    "Choose a file to add as attachment" : "Hautatu fitxategia gehitzeko eranskin gisa",
    "Delete" : "Ezabatu",
    "Import into calendar" : "Egutegian inportatu",
    "Download attachment" : "Eranskina jaitsi",
    "Save to Files" : "Fitxategitan gorde",
    "Choose a folder to store the attachment in" : "Hautatu karpeta bat eranskina gordetzeko",
    "Save all to Files" : "Dena fitxategitan gorde",
    "The images have been blocked to protect your privacy." : "Irudiak blokeatu dira zure segurtasunerako",
    "New message" : "Mezu berria",
    "Settings" : "Ezarpenak",
    "Show all folders" : "Erakutsi karpeta guztiak",
    "Collapse folders" : "Bildu karpetak",
    "Speed up your Mail experience with these quick shortcuts." : "Zure Mail erabilpena azkartu lasterbide azkar hauekin",
    "Compose new message" : "Mezu berria idatzi",
    "Newer message" : "Mezu berriagoa",
    "Older message" : "Mezu zaharragoa",
    "Toggle star" : "Izarra aldatu",
    "Toggle unread" : "Irakurria aldatu",
    "Search" : "Bilatu",
    "Refresh" : "Birkargatu",
    "Connect your mail account" : "Konektatu zure eposta kontua",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mezu berri \njaso dituzu {from}-etik","%n mezu berri \njaso dituzu {from}-etik"],
    "Nextcloud Mail" : "Nextcloud eposta",
    "All inboxes" : "Postontzi guztiak",
    "Could not load {tag}{name}{endtag}" : "Ezin izan da {tag}{name}{endtag} kargatu",
    "There was a problem loading {tag}{name}{endtag}" : "Arazo bat egon da {tag}{name}{endtag} kargatzerakoan",
    "Error loading message" : "Errorea mezua kargatzerakoan",
    "Forwarding to %s" : "%s birbidaltzen",
    "Click here if you are not automatically redirected within the next few seconds." : "Sakatu hemen hurrengo segunduetan automatikoki birbideratzen ez bada.",
    "Redirect" : "Birbideratu",
    "The link leads to %s" : "Estekak 1%s-ra apuntatzen du",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ez baduzu webgune horretara joan nahi <a href=\"%s\">Mail</a>  webgunera itzul zaitezke",
    "Continue to %s" : "1%s-ra jarraitu"
},
"nplurals=2; plural=(n != 1);");
